diff --git a/Server/Components/AICore/AICore.csproj b/Server/Components/AICore/AICore.csproj
index 69d2e60a7..1eec54294 100644
--- a/Server/Components/AICore/AICore.csproj
+++ b/Server/Components/AICore/AICore.csproj
@@ -108,21 +108,21 @@
-
+
-
+
-
+
-
+
-
+
-
+
diff --git a/Server/Components/AICore/Prompt/SystemInstruction/AiConversationSystemInstructionBuilder.cs b/Server/Components/AICore/Prompt/SystemPrompts/AiConversationSystemPromptBuilder.cs
similarity index 80%
rename from Server/Components/AICore/Prompt/SystemInstruction/AiConversationSystemInstructionBuilder.cs
rename to Server/Components/AICore/Prompt/SystemPrompts/AiConversationSystemPromptBuilder.cs
index 4c82f38b7..c1dc30e15 100644
--- a/Server/Components/AICore/Prompt/SystemInstruction/AiConversationSystemInstructionBuilder.cs
+++ b/Server/Components/AICore/Prompt/SystemPrompts/AiConversationSystemPromptBuilder.cs
@@ -12,19 +12,19 @@ using System.Reflection;
using System.Text;
using System.Text.Json;
-namespace AICore.Prompt.SystemInstruction
+namespace AICore.Prompt.SystemPrompts
{
- public class AiConversationSystemInstructionBuilder : BaseSystemInstructionBuilder
+ public class AiConversationSystemPromptBuilder : BaseSystemPromptBuilder
{
- public AiConversationSystemInstructionBuilder(string prompt_path) : base(prompt_path) {
+ public AiConversationSystemPromptBuilder(string prompt_path) : base(prompt_path) {
}
- public string CreateSystemInstructions(AiContextType uicontext, BaseContextSummary context, AiDataContextType aiDataContextType)
+ public string CreateSystemPrompt(AiContextType uicontext, BaseContextSummary context, AiDataContextType aiDataContextType)
{
var sb = new StringBuilder();
- sb.AppendLine(getCustomSystemPrompt("customSystemInstruction.txt"));
+ sb.AppendLine(getCustomSystemPrompt("customPreSystemPrompt.txt"));
sb.AppendLine("### **Allgemein**");
sb.AppendLine($"- Aktuelle Zeit: {DateTime.Now}");
diff --git a/Server/Components/AICore/Prompt/SystemInstruction/AiFunctionSystemInstructionBuilder.cs b/Server/Components/AICore/Prompt/SystemPrompts/AiFunctionSystemPromptBuilder.cs
similarity index 74%
rename from Server/Components/AICore/Prompt/SystemInstruction/AiFunctionSystemInstructionBuilder.cs
rename to Server/Components/AICore/Prompt/SystemPrompts/AiFunctionSystemPromptBuilder.cs
index ad38689bb..401a0c4ef 100644
--- a/Server/Components/AICore/Prompt/SystemInstruction/AiFunctionSystemInstructionBuilder.cs
+++ b/Server/Components/AICore/Prompt/SystemPrompts/AiFunctionSystemPromptBuilder.cs
@@ -11,20 +11,20 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace AICore.Prompt.SystemInstruction
+namespace AICore.Prompt.SystemPrompts
{
- public class AiFunctionSystemInstructionBuilder : BaseSystemInstructionBuilder
+ public class AiFunctionSystemPromptBuilder : BaseSystemPromptBuilder
{
- public AiFunctionSystemInstructionBuilder(string prompt_path) : base(prompt_path)
+ public AiFunctionSystemPromptBuilder(string prompt_path) : base(prompt_path)
{
}
- public string CreateServiceRecordDocumentationSystemInstructions(BaseContextSummary context)
+ public string CreateServiceRecordDocumentationSystemPrompt(BaseContextSummary context)
{
var sb = new StringBuilder();
- sb.AppendLine(getCustomSystemPrompt("customFunctionSystemInstruction.txt"));
+ sb.AppendLine(getCustomSystemPrompt("customFunctionPreSystemPrompt.txt"));
sb.AppendLine("### **Allgemein**");
sb.AppendLine($"- Aktuelle Zeit: {DateTime.Now}");
diff --git a/Server/Components/AICore/Prompt/SystemInstruction/BaseSystemInstructionBuilder.cs b/Server/Components/AICore/Prompt/SystemPrompts/BaseSystemPromptBuilder.cs
similarity index 74%
rename from Server/Components/AICore/Prompt/SystemInstruction/BaseSystemInstructionBuilder.cs
rename to Server/Components/AICore/Prompt/SystemPrompts/BaseSystemPromptBuilder.cs
index 373a95000..30a9f8c4e 100644
--- a/Server/Components/AICore/Prompt/SystemInstruction/BaseSystemInstructionBuilder.cs
+++ b/Server/Components/AICore/Prompt/SystemPrompts/BaseSystemPromptBuilder.cs
@@ -5,13 +5,13 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace AICore.Prompt.SystemInstruction
+namespace AICore.Prompt.SystemPrompts
{
- public class BaseSystemInstructionBuilder
+ public class BaseSystemPromptBuilder
{
public string SystemPromptFolderPath { get; set; }
- public BaseSystemInstructionBuilder(string systemPromptFolderPath)
+ public BaseSystemPromptBuilder(string systemPromptFolderPath)
{
SystemPromptFolderPath = systemPromptFolderPath;
}
diff --git a/Service/Plugins/AiFunctionService.cs b/Service/Plugins/AiFunctionService.cs
index 722900736..711e06fc2 100644
--- a/Service/Plugins/AiFunctionService.cs
+++ b/Service/Plugins/AiFunctionService.cs
@@ -14,7 +14,7 @@ using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
-using AICore.Prompt.SystemInstruction;
+using AICore.Prompt.SystemPrompts;
using BeWo.Service.Core;
namespace BeWo.Service.Plugins
@@ -32,9 +32,9 @@ namespace BeWo.Service.Plugins
// Anfrage zusammensetzen
var context = AiFunctionContextLoader.LoadServiceRecordDocumentationContext(request);
- var systemInstructionsFolderPath = PathHelper.GetAiSystemInstructionPath();
- var factory = new AiFunctionSystemInstructionBuilder(systemInstructionsFolderPath);
- var system_prompt = factory.CreateServiceRecordDocumentationSystemInstructions(context);
+ var systemPromptFolderPath = PathHelper.GetAiSystemPromptPath();
+ var factory = new AiFunctionSystemPromptBuilder(systemPromptFolderPath);
+ var system_prompt = factory.CreateServiceRecordDocumentationSystemPrompt(context);
var user_prompt = request.AiPromptbaustein;
var user_prompt_oid = user_prompt.Oid;
diff --git a/Service/Plugins/AiService2.cs b/Service/Plugins/AiService2.cs
index 0a821e30c..57b215b7e 100644
--- a/Service/Plugins/AiService2.cs
+++ b/Service/Plugins/AiService2.cs
@@ -9,7 +9,7 @@ using System.ServiceModel;
using System.Text;
using System.Web.Hosting;
using AICore.Prompt.Core;
-using AICore.Prompt.SystemInstruction;
+using AICore.Prompt.SystemPrompts;
using BeWo.Data.Access;
using BeWo.Data.Entities;
using BeWo.Data.Security;
@@ -272,11 +272,11 @@ namespace BeWo.Service.Plugins
{
var current_user = UserRightHelper.GetLoggedInUserWithOid();
- var systemInstructionsFolderPath = PathHelper.GetAiSystemInstructionPath();
- var factory = new AiConversationSystemInstructionBuilder(systemInstructionsFolderPath);
+ var systemPromptFolderPath = PathHelper.GetAiSystemPromptPath();
+ var factory = new AiConversationSystemPromptBuilder(systemPromptFolderPath);
var context_loaded = AiContextLoader.LoadContext(uicontext, context_reference);
- var system_prompt = factory.CreateSystemInstructions(uicontext, context_loaded, context_Type);
+ var system_prompt = factory.CreateSystemPrompt(uicontext, context_loaded, context_Type);
var conv = new AiConversation();
conv.Created = DateTime.Now;
diff --git a/Server/Components/AICore/Prompt/SystemPrompts/system_prompt1.txt b/Server/Components/AICore/Prompt/SystemPrompts/Examples/system_prompt1.txt
similarity index 100%
rename from Server/Components/AICore/Prompt/SystemPrompts/system_prompt1.txt
rename to Server/Components/AICore/Prompt/SystemPrompts/Examples/system_prompt1.txt
diff --git a/Server/Components/AICore/Prompt/SystemPrompts/system_prompt2.txt b/Server/Components/AICore/Prompt/SystemPrompts/Examples/system_prompt2.txt
similarity index 100%
rename from Server/Components/AICore/Prompt/SystemPrompts/system_prompt2.txt
rename to Server/Components/AICore/Prompt/SystemPrompts/Examples/system_prompt2.txt
diff --git a/Server/Components/AICore/Prompt/SystemPrompts/system_prompt3.txt b/Server/Components/AICore/Prompt/SystemPrompts/Examples/system_prompt3.txt
similarity index 100%
rename from Server/Components/AICore/Prompt/SystemPrompts/system_prompt3.txt
rename to Server/Components/AICore/Prompt/SystemPrompts/Examples/system_prompt3.txt
diff --git a/Service/Core/PathHelper.cs b/Service/Core/PathHelper.cs
index 2928ae6a3..e6291f988 100644
--- a/Service/Core/PathHelper.cs
+++ b/Service/Core/PathHelper.cs
@@ -11,10 +11,10 @@ namespace BeWo.Service.Core
public static class PathHelper
{
///
/// Holt den Ordner, wo sich die systemInstructions befinden
///
- public static string GetAiSystemInstructionPath()
- => Path.Combine(getRoot(), "AI", "systemInstructions");
+ public static string GetAiSystemPromptPath()
+ => Path.Combine(getRoot(), "AI", "systemPrompts");
public static string GetUniqueRequestLogFile()
@@ -11,10 +11,10 @@ namespace BeWo.Service.Core
{
///
- /// Holt den Ordner, wo sich die systemInstructions befinden
+ /// Holt den Ordner, wo sich die systemPrompts befinden
///